// import auth from '@/plugins/auth'
import useUserStore from '@/store/modules/user'
import router, { constantRoutes, dynamicRoutes } from '@/router'
import { getRouters } from '@/api/menu'
import Layout from '@/layout/index'
import ParentView from '@/components/ParentView'
import InnerLink from '@/layout/components/InnerLink'

// 匹配views里面所有的.vue文件
const modules = import.meta.glob('./../../views/**/*.vue')

const usePermissionStore = defineStore(
  'permission',
  {
    state: () => ({
      routes: [],
      addRoutes: [],
      defaultRoutes: [],
      topbarRouters: [],
      sidebarRouters: [],
      indexPath: "/",
      cacheRouters: []
    }),
    actions: {
      setRoutes(routes) {
        this.addRoutes = routes
        this.routes = constantRoutes.concat(routes)
      },
      setDefaultRoutes(routes) {
        this.defaultRoutes = constantRoutes.concat(routes)
      },
      setTopbarRoutes(routes) {
        this.topbarRouters = routes
      },
      setcacheRouters(routes) {
        this.cacheRouters = routes
      },
      setSidebarRouters(routes) {
        this.sidebarRouters = routes
      },
      generateRoutes() {
        return new Promise((resolve, reject) => {
          getRouters().then(res => {
            const localRoutes = filterDynamicRoutes(dynamicRoutes)
            const accessedRoutes = [...filterDynamicRoutes(res.data), ...localRoutes]
            const sdata = JSON.parse(JSON.stringify(accessedRoutes))
            const rdata = JSON.parse(JSON.stringify(accessedRoutes))
            const defaultData = JSON.parse(JSON.stringify(accessedRoutes))
            const sidebarRoutes = filterAsyncRouter(sdata)
            const rewriteRoutes = filterAsyncRouter(rdata, false, true)
            const defaultRoutes = filterAsyncRouter(defaultData)
            this.cacheRouters = mergePaths(constantRoutes.concat(sidebarRoutes))
            this.indexPath = this.cacheRouters && this.cacheRouters.length > 0 ? getFirstObj(this.cacheRouters[0]).fullPath : "/401"
            this.setRoutes(rewriteRoutes)
            this.setSidebarRouters(constantRoutes.concat(sidebarRoutes))
            this.setDefaultRoutes(sidebarRoutes)
            this.setTopbarRoutes(defaultRoutes)
            resolve(rewriteRoutes)
          })
          //过滤本地路由
          // const accessedRoutes = filterDynamicRoutes(dynamicRoutes)
          // const sdata = JSON.parse(JSON.stringify(accessedRoutes))
          // const rdata = JSON.parse(JSON.stringify(accessedRoutes))
          // const defaultData = JSON.parse(JSON.stringify(accessedRoutes))
          // const sidebarRoutes = filterAsyncRouter(sdata)
          // const rewriteRoutes = filterAsyncRouter(rdata, false, true)
          // const defaultRoutes = filterAsyncRouter(defaultData)

          // this.setRoutes(rewriteRoutes)
          // this.setSidebarRouters(constantRoutes.concat(sidebarRoutes))
          // this.setDefaultRoutes(sidebarRoutes)
          // this.setTopbarRoutes(defaultRoutes)
          // resolve(rewriteRoutes)
        })
      }
    }
  })
function mergePaths(tree, parentPath = '') {
  let shallowTree = JSON.parse(JSON.stringify(tree));
  shallowTree = shallowTree.filter(node => !node.hidden);
  return shallowTree.map(node => {
    const fullPath = parentPath === '/' || parentPath === '' ? parentPath + node.path : `${parentPath}/${node.path}`;
    if (node.children && node.children.length > 0) {
      node.children = mergePaths(node.children, fullPath);
    }
    return { ...node, fullPath };
  });
}
function getFirstObj(obj) {
  if (!obj.children || obj.children.length === 0) {
    return obj;
  }
  return getFirstObj(obj.children[0]);
}
// 遍历后台传来的路由字符串，转换为组件对象
function filterAsyncRouter(asyncRouterMap, lastRouter = false, type = false) {
  return asyncRouterMap.filter(route => {
    if (type && route.children) {
      route.children = filterChildren(route.children)
    }
    if (route.component) {
      // Layout ParentView 组件特殊处理
      if (route.component === 'Layout') {
        route.component = Layout
      } else if (route.component === 'ParentView') {
        route.component = ParentView
      } else if (route.component === 'InnerLink') {
        route.component = InnerLink
      } else {
        route.component = loadView(route.component)
      }
    }
    if (route.children != null && route.children && route.children.length) {
      route.children = filterAsyncRouter(route.children, route, type)
    } else {
      delete route['children']
      delete route['redirect']
    }
    return true
  })
}

function filterChildren(childrenMap, lastRouter = false) {
  var children = []
  childrenMap.forEach((el, index) => {
    if (el.children && el.children.length) {
      if (el.component === 'ParentView' && !lastRouter) {
        el.children.forEach(c => {
          c.path = el.path + '/' + c.path
          if (c.children && c.children.length) {
            children = children.concat(filterChildren(c.children, c))
            return
          }
          children.push(c)
        })
        return
      }
    }
    if (lastRouter) {
      el.path = lastRouter.path + '/' + el.path
    }
    children = children.concat(el)
  })
  return children
}

// 动态路由遍历，验证是否具备权限
export function filterDynamicRoutes(routes) {
  const permissions = useUserStore().permissions
  function deppFilter(routes) {
    let allowMenu = [];
    if (routes instanceof Array) {
      routes.forEach(route => {
        if (route.children && route.children.length) {
          if (route.meta && route.meta.permission) {
            if (permissions.includes(route.meta.permission)) {
              allowMenu.push({
                ...route,
                children: deppFilter(route.children)
              })
            }
          } else {
            allowMenu.push({
              ...route,
              children: deppFilter(route.children)
            })
          }
        } else {
          if (route.meta && route.meta.permission) {
            if (permissions.includes(route.meta.permission)) {
              allowMenu.push(route)
            }
          } else {
            allowMenu.push(route)
          }
        }
      })
    } else if (routes instanceof Object) {
      if (routes.children && routes.children.length) {
        allowMenu.push({
          ...routes,
          children: deppFilter(routes.children)
        })
      } else {
        if (routes.meta && routes.meta.permission) {
          if (!permissions.includes(routes.meta.permission)) {
            allowMenu = [routes]
          }
        } else {
          allowMenu = [routes]
        }
      }
    }
    return allowMenu;
  }
  let allowMenu = permissions.includes("*:*:*") ? routes : deppFilter(routes)
  return allowMenu.filter(route => !route.children || route?.children?.length > 0)
}

export const loadView = (view) => {
  let res;
  for (const path in modules) {
    const dir = path.split('views/')[1].split('.vue')[0];
    if (dir === view) {
      res = () => modules[path]();
    }
  }
  return res;
}

export default usePermissionStore
